@@ -7,8 +7,7 @@ use Alien::Build::Plugin;
 use Module::Load ();
 
 # ABSTRACT: Plugin to extract links from HTML using Mojo::DOM or Mojo::DOM58
-our $VERSION = '0.04_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '0.01'; # VERSION
 
 
 sub _load ($)
@@ -96,25 +95,12 @@ Alien::Build::Plugin::Decode::Mojo - Plugin to extract links from HTML using Moj
 
 =head1 VERSION
 
-version 0.04_01
+version 0.01
 
 =head1 SYNOPSIS
 
  use alienfile;
- plugin 'Decode::Mojo';
-
-Force using C<Decode::Mojo> via the download negotiator:
-
- use alienfile 1.68;
- 
- configure {
-   requires 'Alien::Build::Plugin::Decod::Mojo';
- };
- 
- plugin 'Download' => (
-   ...
-   decoder => 'Decode::Mojo',
- );
+ use 'Decode::Mojo';
 
 =head1 DESCRIPTION
 
